/* File: config.h
 * Desc: Media independant (memory assumed) definitions on configuration data
 * Auth: San Mehat (mods by Mark Knox)
 * Note:
 */

#ifndef CONFIG_H
#define CONFIG_H

#define OPT_INCLUDE_NONE 1
#define OPT_INCLUDE_NOEXEC 2
#define OPT_INCLUDE_FULL 3

#include <net/route.h> 
typedef struct config_nodelist
{
	int                    I_nodenumber;
	unsigned int           UI_throughputchoke;
	unsigned char          UC_priority;
	struct config_nodelist *next;
} CONFIG_NODELIST;

typedef struct config_partition
{
	char		SZ_servername[64];
	char		C_optionflags;
	unsigned int	UI_aliasaddr;   // External network addr alias for partition
	unsigned int	UI_aliasmask;   // External network address netmask
	unsigned short	US_portbinding; // Port to forward to on slave for partition
	char		SZ_documentpath[80];	// FQ docpath to fs mountpoint
	char		SZ_cgipath[80]; 	// FQ cgipath to fs mountpoint
	char		SZ_loadbalancer[80];	// Load balancing modulename
	char		C_ssl;					// 0 => SSL disabled, 1 => SSL enabled
	char		SZ_sslcertificate[80];	// SSL certificate file

	struct rtentry	Srtentry_route;
	CONFIG_NODELIST *Tnodelist_root;
	struct config_partition *next;
} CONFIG_PARTITION;

typedef struct CONFIGURATION
{
	char		SZ_servername[80];	// server's host and domain name
	unsigned int	UI_ext_ipaddr, UI_ext_netmask,
			UI_int_ipaddr, UI_int_netmask,
			UI_gateway, UI_nameserver,
			UI_syncmngrscanfreq, UI_cardsvcsscanfreq;
	struct rtentry	Srtentry_route[6];
	unsigned char	UC_slavememthrottle;
	unsigned char	UC_ctrletheraddr[6];
	char		SZ_timezone[50];	// timezone string
	unsigned int	UI_nfsserver;		// nfs server addr
	char		SZ_binarypath[80];	// nfs arm binary path
	char		SZ_globalloadbalancer[80];	// LB for name-based virtual hosting
	char		SZ_email[80];	// the sys admin's email address
	CONFIG_PARTITION *Tpartition_root;
} CONFIGURATION;


#ifdef __cplusplus
extern "C"
{
#endif

char* mytime();
int config_load(CONFIGURATION*);
int config_save(CONFIGURATION*);
void destroy_partitions(CONFIGURATION*);
char *itod(int);
unsigned int dtoi(char*);
void serverToHostAndDomain(char*, char*, char*);
int getCardServicesPID();

#ifdef __cplusplus
}
#endif

enum
{
	HOSTNAME,
	DOMAIN,
	EXTERNAL_IPADDR,
	EXTERNAL_NETMASK,
	INTERNAL_IPADDR,
	INTERNAL_NETMASK,
	GATEWAY,
	NAMESERVER,
	INTERVAL,
	LOADBAL,
	SERVERADMIN,
	TIMEZONE,
	TIMEDATE,
	NFSSERV,
	NFSBIN,
	NFSDOC,
	NETADDR,

	SERVERNAME,

	V_HOSTNAME,
	V_DOMAIN,
	V_IPADDR,
	V_PORT,
	V_DOCROOT,
	V_CGIROOT,
	V_SSL,
	V_SSLCERTIFICATE,
	V_INCLUDES,
	V_LOADBAL,
	V_NODELIST,

	ITEM_MAX
};

#define FIELD_MAX	128

extern char Stored[ITEM_MAX][FIELD_MAX];

#define ZAPHOD_DIRECTORY	"/tmp/zaphod/"
#define ZAPHOD_CONFIG_DIRECTORY	ZAPHOD_DIRECTORY "conf/"
#define ZAPHOD_SYSCONFIG_FILE	ZAPHOD_CONFIG_DIRECTORY "zaphod.cfg"
#define ZAPHOD_CONFIG_FILE1	ZAPHOD_SYSCONFIG_FILE "1"
#define ZAPHOD_CONFIG_FILE2	ZAPHOD_SYSCONFIG_FILE "2"
#define ZAPHOD_APACHE_FILE	ZAPHOD_CONFIG_DIRECTORY "zaphod.httpsd.conf"
#define APACHE_DEFAULTS_FILE	ZAPHOD_CONFIG_DIRECTORY "defaults.httpsd.conf"
#define APACHE_CONFIG_FILE	"httpsd.conf"
#define CARD_SERVICES_PID_FILE	"/var/run/CardServices.pid"

#endif // CONFIG_H
